==> nmrium-0.49.0.tgz: package/lib/component/modal/changeSum/ChangeSumModalContents.js <==
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import styled from '@emotion/styled';
import { Formik } from 'formik';
import { useEffect, useRef, useState } from 'react';
import { Modal } from 'react-science/ui';
import * as Yup from 'yup';
import { usePreferences } from '../../context/PreferencesContext';
import Button from '../../elements/Button';
import Tab from '../../elements/Tab/Tab';
import Tabs from '../../elements/Tab/Tabs';
import FormikInput from '../../elements/formik/FormikInput';
import SelectMolecule from './SelectMolecule';
function getValidationSchema(option) {
    switch (option) {
        case 'auto': {
            return Yup.object({
                molecule: Yup.object().required(),
            });
        }
        case 'manual': {
            return Yup.object({
                sum: Yup.number().required(),
            });
        }
        default:
            return null;
    }
}
const ManualContainer = styled.div `
  padding: 30px 5px;

  .input {
    width: 80% !important;
    height: 36px;
    margin: 0 auto;
  }

  .input input {
    padding: 5px;
    text-align: center;
  }
`;
export function ChangeSumModalContents(props) {
    const { currentSum, sumType, sumOptions, onSave, onClose } = props;
    const { current: { display: { panels }, }, } = usePreferences();
    const [setOption, setActiveOption] = useState('auto');
    const formRef = useRef(null);
    useEffect(() => {
        if (sumOptions?.sumAuto && panels?.structuresPanel?.display) {
            setActiveOption('auto');
            const { mf, moleculeId: id } = sumOptions;
            formRef.current.setValues({
                sum: null,
                molecule: id && mf ? { mf, id } : null,
            });
        }
        else {
            setActiveOption('manual');
            formRef.current.setValues({
                sum: sumOptions?.sum ?? '',
                molecule: null,
            });
        }
    }, [panels?.structuresPanel, sumOptions]);
    function handleKeyDown(event) {
        if (event.key === 'Enter') {
            formRef.current.submitForm();
        }
    }
    function onTabChangeHandler(tab) {
        setActiveOption(tab.tabid);
    }
    function saveHandler(values) {
        switch (setOption) {
            case 'auto': {
                const { molecule: { mf, id: moleculeId }, } = values;
                onSave({ sumAuto: true, mf, moleculeId });
                break;
            }
            case 'manual': {
                const { sum } = values;
                onSave({ sum, sumAuto: false });
                break;
            }
            default:
                return;
        }
        onClose();
    }
    const isStructurePanelVisible = panels?.structuresPanel?.display || false;
    return (_jsxs(_Fragment, { children: [_jsx(Modal.Header, { children: currentSum
                    ? `Set new ${sumType} sum (Current: ${currentSum.toFixed(2)})`
                    : `Set new ${sumType} Sum` }), _jsx(Modal.Body, { children: _jsx(Formik, { innerRef: formRef, onSubmit: saveHandler, initialValues: { sum: '', molecule: null }, validationSchema: getValidationSchema(setOption), children: _jsxs(Tabs, { activeTab: setOption, onClick: onTabChangeHandler, children: [isStructurePanelVisible && (_jsx(Tab, { title: "Auto", tabid: "auto", children: _jsx(SelectMolecule, { name: "molecule" }) })), _jsx(Tab, { title: "Manual", tabid: "manual", children: _jsx(ManualContainer, { children: _jsx(FormikInput, { name: "sum", type: "number", placeholder: "Enter the new value", onKeyDown: handleKeyDown }) }) })] }) }) }), _jsx(Modal.Footer, { children: _jsx(Button.Done, { onClick: () => formRef.current.submitForm(), style: { width: 80 }, children: "Set" }) })] }));
}

==> nmrium-0.50.1.tgz: package/lib/component/modal/changeSum/ChangeSumModalContents.js <==
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { DialogBody, DialogFooter } from '@blueprintjs/core';
import { css } from '@emotion/react';
import styled from '@emotion/styled';
import { Formik } from 'formik';
import { useEffect, useRef, useState } from 'react';
import * as Yup from 'yup';
import { usePreferences } from '../../context/PreferencesContext';
import Button from '../../elements/Button';
import Tab from '../../elements/Tab/Tab';
import Tabs from '../../elements/Tab/Tabs';
import FormikInput from '../../elements/formik/FormikInput';
import SelectMolecule from './SelectMolecule';
function getValidationSchema(option) {
    switch (option) {
        case 'auto': {
            return Yup.object({
                molecule: Yup.object().required(),
            });
        }
        case 'manual': {
            return Yup.object({
                sum: Yup.number().required(),
            });
        }
        default:
            return null;
    }
}
const ManualContainer = styled.div `
  padding: 30px 5px;

  .input {
    width: 80% !important;
    height: 36px;
    margin: 0 auto;
  }

  .input input {
    padding: 5px;
    text-align: center;
  }
`;
export function ChangeSumModalContents(props) {
    const { sumOptions, onSave, onClose } = props;
    const { current: { display: { panels }, }, } = usePreferences();
    const [setOption, setActiveOption] = useState('auto');
    const formRef = useRef(null);
    useEffect(() => {
        if (sumOptions?.sumAuto && panels?.structuresPanel?.display) {
            setActiveOption('auto');
            const { mf, moleculeId: id } = sumOptions;
            formRef.current.setValues({
                sum: null,
                molecule: id && mf ? { mf, id } : null,
            });
        }
        else {
            setActiveOption('manual');
            formRef.current.setValues({
                sum: sumOptions?.sum ?? '',
                molecule: null,
            });
        }
    }, [panels?.structuresPanel, sumOptions]);
    function handleKeyDown(event) {
        if (event.key === 'Enter') {
            formRef.current.submitForm();
        }
    }
    function onTabChangeHandler(tab) {
        setActiveOption(tab.tabid);
    }
    function saveHandler(values) {
        switch (setOption) {
            case 'auto': {
                const { molecule: { mf, id: moleculeId }, } = values;
                onSave({ sumAuto: true, mf, moleculeId });
                break;
            }
            case 'manual': {
                const { sum } = values;
                onSave({ sum, sumAuto: false });
                break;
            }
            default:
                return;
        }
        onClose();
    }
    const isStructurePanelVisible = panels?.structuresPanel?.display || false;
    return (_jsxs(_Fragment, { children: [_jsx(DialogBody, { css: css `
          padding: 0;
          background-color: white;
        `, children: _jsx(Formik, { innerRef: formRef, onSubmit: saveHandler, initialValues: { sum: '', molecule: null }, validationSchema: getValidationSchema(setOption), children: _jsxs(Tabs, { activeTab: setOption, onClick: onTabChangeHandler, children: [isStructurePanelVisible && (_jsx(Tab, { title: "Auto", tabid: "auto", children: _jsx(SelectMolecule, { name: "molecule" }) })), _jsx(Tab, { title: "Manual", tabid: "manual", children: _jsx(ManualContainer, { children: _jsx(FormikInput, { name: "sum", type: "number", placeholder: "Enter the new value", onKeyDown: handleKeyDown }) }) })] }) }) }), _jsx(DialogFooter, { children: _jsx(Button.Done, { onClick: () => formRef.current.submitForm(), style: { width: 80 }, children: "Set" }) })] }));
}
